Crate arch_mirrors_rs

Crate arch_mirrors_rs 

Arch Mirrors

Get and parse the Arch Linux mirrors.

Re-exports

pub use crate::mirror::Mirror;
pub use protocol::Protocol;
pub use status::Status;

Modules

mirror
This is where the [Url] struct and all of its dependencies go.
protocol
This is where the Protocol structs and its dependencies go.
status
This is where the Status struct and all of its direct dependencies go.